@@ -24,12 +24,15 @@ from zenml.core.standards import standard_keys as keys
 from zenml.utils import path_utils
 from zenml.utils import source_utils
 from zenml.utils.enums import GDPComponent
+from zenml.utils.logger import get_logger
 from zenml.utils.post_training.post_training_utils import \
-    get_schema_artifact, view_schema, get_feature_spec_from_schema, \
-    convert_raw_dataset_to_pandas, get_statistics_artifact, view_statistics
+    view_schema, get_feature_spec_from_schema, \
+    convert_raw_dataset_to_pandas, view_statistics
 from zenml.utils.print_utils import to_pretty_string, PrintStyles
 from zenml.utils.zenml_analytics import track, CREATE_DATASOURCE
 
+logger = get_logger(__name__)
+
 
 class BaseDatasource:
     """Base class for all ZenML datasources.
@@ -54,20 +57,23 @@ class BaseDatasource:
             self._id = _id
             self._source = _source
             self._immutable = True
+            logger.debug(f'Datasource {name} loaded.')
         else:
             # If none, then this is assumed to be 'new'. Check dupes.
             all_names = Repository.get_instance().get_datasource_names()
             if any(d == name for d in all_names):
                 raise Exception(
                     f'Datasource {name} already exists! Please '
-                    f'use Repository.get_datasource_by_name("{name}") '
-                    f'to fetch.')
+                    f'use Repository.get_instance().'
+                    f'get_datasource_by_name("{name}") to fetch it.')
             self._id = str(uuid4())
             self._immutable = False
             self._source = source_utils.resolve_source_path(
                 self.__class__.__module__ + '.' + self.__class__.__name__
             )
             track(event=CREATE_DATASOURCE)
+            logger.info(f'Datasource {name} created.')
+
         self.name = name
         self.schema = schema
 
@@ -146,10 +152,8 @@ class BaseDatasource:
         if pipeline.datasource._id != self._id:
             raise AssertionError('This pipeline does not belong to this '
                                  'datasource.')
-        repo: Repository = Repository.get_instance()
         # Take any pipeline and get the datagen
-        data_uri = os.path.join(repo.get_artifacts_uri_by_component(
-            pipeline.pipeline_name,
+        data_uri = os.path.join(pipeline.get_artifacts_uri_by_component(
             GDPComponent.DataGen.name
         )[0], 'examples')
         data_files = path_utils.list_dir(data_uri)
@@ -165,8 +169,8 @@ class BaseDatasource:
         pipeline = self._get_one_pipeline()
         data_files = self._get_data_file_paths(pipeline)
 
-        schema_uri = get_schema_artifact(
-            pipeline.pipeline_name, GDPComponent.DataSchema.name)
+        schema_uri = pipeline.get_artifacts_uri_by_component(
+            GDPComponent.DataSchema.name)[0]
         spec = get_feature_spec_from_schema(schema_uri)
 
         dataset = tf.data.TFRecordDataset(data_files, compression_type='GZIP')
@@ -183,13 +187,13 @@ class BaseDatasource:
     def view_schema(self):
         """View schema of data flowing in pipeline."""
         pipeline = self._get_one_pipeline()
-        uri = get_schema_artifact(
-            pipeline.pipeline_name, GDPComponent.DataSchema.name)
+        uri = pipeline.get_artifacts_uri_by_component(
+            GDPComponent.DataSchema.name)[0]
         view_schema(uri)
 
     def view_statistics(self):
         """View statistics of data flowing in pipeline."""
         pipeline = self._get_one_pipeline()
-        uri = get_statistics_artifact(
-            pipeline.pipeline_name, GDPComponent.DataStatistics.name)
+        uri = pipeline.get_artifacts_uri_by_component(
+            GDPComponent.DataStatistics.name)[0]
         view_statistics(uri)
