@@ -35,6 +35,14 @@ def lint_split_map(split_map: Dict[Text, float]):
 
 
 class CategoricalRatioSplit(BaseSplit):
+    """
+    Categorical ratio split. Use this to split data based on a list of values
+    of interest in a single categorical column. A categorical column is
+    defined here as a column with finitely many values of type `integer` or
+    `string`. In contrast to the categorical domain split, here categorical
+    values are assigned to different splits by the corresponding percentages,
+    defined inside a split ratio object.
+    """
 
     def __init__(
             self,
@@ -45,13 +53,37 @@ class CategoricalRatioSplit(BaseSplit):
             schema=None,
     ):
         """
+        Categorical domain split constructor.
+
+        Use this class to split your data based on values in
+        a single categorical column. A categorical column is defined here as a
+        column with finitely many values of type `integer` or `string`.
+
+        Example usage:
+
+        # Split on a categorical attribute called "color", with a defined list
+        of categories of interest
+
+        # half of the categories go entirely into the train set,
+          the other half into the eval set
+
+        >>> split = CategoricalRatioSplit(
+        ... categorical_column="color",
+        ... categories = ["red", "green", "blue", "yellow"],
+        ... split_ratio = {"train": 0.5,
+        ...                "eval": 0.5})
+
+        Any data point with a categorical value that is not present in the
+        `categories` list will by default be put into the eval set.
 
         Args:
             statistics: Parsed statistics from a preceding StatisticsGen.
             schema: Parsed schema from a preceding SchemaGen.
             categorical_column: Name of the categorical column used for
-                                splitting.
-            split_ratio: A dict { split_name: percentage of categories
+             splitting.
+            categories: List of categorical values found in the categorical
+             column on which to split.
+            split_ratio: A dict mapping { split_name: percentage of categories
                                     in split }.
         """
         self.categorical_column = categorical_column
